@@ -3,3 +3,6 @@
 
 /* jpeg lib */
 #undef HAVE_LIBJPEG
+
+/* lirc lib */
+#undef HAVE_LIBLIRC_CLIENT
